@@ -35,11 +35,10 @@ use HTML::FormFu::Util qw(
     _filter_components
 );
 
+use Clone ();
 use List::Util qw( first );
 use List::MoreUtils qw( any none uniq );
 use Scalar::Util qw( blessed refaddr reftype weaken );
-use Storable qw( dclone );
-use Regexp::Copy;
 use Carp qw( croak );
 
 use overload (
@@ -112,7 +111,7 @@ __PACKAGE__->mk_inherited_merging_accessors(qw( tt_args config_callback ));
 *plugins           = \&plugin;
 *add_plugins       = \&add_plugin;
 
-our $VERSION = '0.06001';
+our $VERSION = '0.07001';
 $VERSION = eval $VERSION;
 
 Class::C3::initialize();
@@ -1115,7 +1114,7 @@ sub _single_output_processor {
         $arg = { type => $arg };
     }
     elsif ( ref $arg eq 'HASH' ) {
-        $arg = dclone($arg);
+        $arg = Clone::clone($arg);
     }
     else {
         croak 'invalid args';
@@ -1484,7 +1483,7 @@ Calling C<< $form->auto_fieldset(1) >> immediately adds a fieldset element to
 the form. Thereafter, C<< $form->elements() >> will add all elements (except
 fieldsets) to that fieldset, rather than directly to the form.
 
-To be specific, the elements are added to the L<last> fieldset on the form,
+To be specific, the elements are added to the I<last> fieldset on the form,
 so if you add another fieldset, any further elements will be added to that
 fieldset.
 
@@ -1607,11 +1606,11 @@ no field errors.
 Arguments: \%defaults
 
 Set defaults which will be added to every element, constraint, etc. of the
-listed type which is added to the form.
+listed type (or derived from the listed type) which is added to the form.
 
-For example, to make every C<Text> element automatically have a
-L<size|HTML::FormFu::Element/size> of C<10>, and make every C<Strftime>
-deflator automatically get its strftime set to C<%d/%m/%Y>:
+For example, to make every C<Text> element automatically have a size of
+C<10>, and make every C<Strftime> deflator automatically get its strftime
+set to C<%d/%m/%Y>:
 
     default_args:
         elements:
@@ -1635,6 +1634,18 @@ get an appropriate Strftime deflator and a DateTime inflator:
                     parser:
                         strptime: '%d-%m-%Y'
 
+To have defaults only be applied to the specific named type, rather than
+searching through derived types, append the type-name with C<+>.
+
+For example, to have the following attributes only be applied to a C<Block>
+element, rather than any element that inherits from C<Block>, such as C<Multi>:
+
+    default_args:
+        elements:
+            +Block:
+                attributes:
+                    class: block
+
 Note: Unlike the proper methods which have aliases, for example L</elements>
 which is an alias for L</element> - the keys given to C<default_args> must
 be of the plural form, e.g.:
@@ -1685,7 +1696,9 @@ Arguments: \@arrayref_of_types_or_options
 Return Value: @elements
 
 Adds a new element to the form. See
-L<HTML::FormFu::Element/"CORE ELEMENTS"> for a list of core elements.
+L<HTML::FormFu::Element/"CORE FORM FIELDS"> and
+L<HTML::FormFu::Element/"OTHER CORE ELEMENTS">
+for a list of core elements.
 
 If you want to load an element from a namespace other than
 C<HTML::FormFu::Element::>, you can use a fully qualified package-name by
@@ -1717,7 +1730,7 @@ Return Value: @deflators
 
 A L<deflator|HTML::FormFu::Deflator> may be associated with any form field,
 and allows you to provide
-L<< $field->default|HTML:FormFu::Element::_Field/default >> with a value
+L<< $field->default|HTML::FormFu::Element::_Field/default >> with a value
 which may be an object.
 
 If an object doesn't stringify to a suitable value for display, the
@@ -1992,7 +2005,7 @@ result after all Filters, Inflators and Transformers have been run.
 Deflators will also be run on the value.
 
 If you set this on a field with an Inflator, but without an equivalent
-Deflator, you should ensure that the Inflators stringify back to a useable
+Deflator, you should ensure that the Inflators stringify back to a usable
 value, so as not to confuse / annoy the user.
 
 Default Value: false
@@ -2192,7 +2205,7 @@ Default Value: "post"
 
 Arguments: [$string]
 
-If set, then all form fields will be given an auto-generated
+If set, then each form field will be given an auto-generated
 L<id|HTML::FormFu::Element/id> attribute, if it doesn't have one already.
 
 The following character substitution will be performed: C<%f> will be
@@ -2212,8 +2225,8 @@ defined value.
 
 Arguments: [$string]
 
-If set, then all form fields will be given an auto-generated
-L<name|HTML::FormFu::Element::Field/label>, if it doesn't have one already.
+If set, then each form field will be given an auto-generated
+L<label|HTML::FormFu::Element::Field/label>, if it doesn't have one already.
 
 The following character substitution will be performed: C<%f> will be
 replaced by L<< $form->id|/id >>, C<%n> will be replaced by
@@ -2233,13 +2246,13 @@ defined value.
 
 Arguments: [$string]
 
-If set, then all form errors will be given an auto-generated class-name.
+If set, then each form error will be given an auto-generated class-name.
 
 The following character substitution will be performed: C<%f> will be
 replaced by L<< $form->id|/id >>, C<%n> will be replaced by
 L<< $field->name|HTML::FormFu::Element/name >>, C<%t> will be replaced by
 L<< lc( $field->type )|HTML::FormFu::Element/type >>, C<%s> will be replaced
-by L<< $error->stage >>.
+by L<< $error->stage|/"FORM LOGIC AND VALIDATION" >>.
 
 Default Value: 'error_%s_%t'
 
@@ -2253,7 +2266,7 @@ defined value.
 
 Arguments: [$string]
 
-If set, then all form fields will be given an auto-generated
+If set, then each form field will be given an auto-generated
 L<message|HTML::FormFu::Exception::Input/message>, if it doesn't have one
 already.
 
@@ -2282,7 +2295,7 @@ defined value.
 
 Arguments: [$string]
 
-If set, then all form fields will be given an auto-generated class-name
+If set, then each form field will be given an auto-generated class-name
 for each associated constraint.
 
 The following character substitution will be performed: C<%f> will be
@@ -2302,7 +2315,7 @@ defined value.
 
 Arguments: [$string]
 
-If set, then all form fields will be given an auto-generated class-name
+If set, then each form field will be given an auto-generated class-name
 for each associated inflator.
 
 The following character substitution will be performed: C<%f> will be
@@ -2322,7 +2335,7 @@ defined value.
 
 Arguments: [$string]
 
-If set, then all form fields will be given an auto-generated class-name
+If set, then each form field will be given an auto-generated class-name
 for each associated validator.
 
 The following character substitution will be performed: C<%f> will be
@@ -2342,7 +2355,7 @@ defined value.
 
 Arguments: [$string]
 
-If set, then all form fields will be given an auto-generated class-name
+If set, then each form field will be given an auto-generated class-name
 for each associated validator.
 
 The following character substitution will be performed: C<%f> will be
@@ -2499,7 +2512,7 @@ Return Value: $input_value
 Return Value: @valid_names
 
 No longer recommended for use, as its behaviour is hard to predict. Use
-L<param_value>, L<param_array> or L<param_list> instead.
+L</param_value>, L</param_array> or L</param_list> instead.
 
 A (readonly) method similar to that of L<CGI's|CGI>.
 
@@ -2709,7 +2722,7 @@ Arguments: [\%constructor_arguments]
 Accepts a hash-ref of arguments passed to L</render_method>, which is called
 internally by L</render>.
 
-Within L</tt>, the keys C<RELATIVE> and C<RECURSION> are overridden to always
+Within tt_args, the keys C<RELATIVE> and C<RECURSION> are overridden to always
 be true, as these are a basic requirement for the L<Template> engine.
 
 The system directory containing HTML::FormFu's template files is always
@@ -2767,7 +2780,7 @@ Arguments: [\%options]
 Return Value: \@elements
 
 Returns all fields in the form (specifically, all elements which have a true
-L<HTML::FormFu::Element/is_field> value.
+L<HTML::FormFu::Element/is_field> value).
 
 Accepts both C<name> and C<type> arguments to narrow the returned results.
 
@@ -3062,21 +3075,21 @@ are copied instead of cloned.
 
 =head2 element_defaults
 
-Is deprecated and provided only for backwards compatability. Will be removed
+Is deprecated and provided only for backwards compatibility. Will be removed
 at some point in the future.
 
 See L</default_args> instead.
 
 =head2 model_class
 
-Is deprecated and provided only for backwards compatability. Will be removed
+Is deprecated and provided only for backwards compatibility. Will be removed
 at some point in the future.
 
 Use L</default_model> instead.
 
 =head2 defaults_from_model
 
-Is deprecated and provided only for backwards compatability. Will be removed
+Is deprecated and provided only for backwards compatibility. Will be removed
 at some point in the future.
 
 Use L<HTML::FormFu::Model/default_values> instead.
@@ -3085,7 +3098,7 @@ Use L<HTML::FormFu::Model/default_values> instead.
 
 =head2 save_to_model
 
-Is deprecated and provided only for backwards compatability. Will be removed
+Is deprecated and provided only for backwards compatibility. Will be removed
 at some point in the future.
 
 Use L<HTML::FormFu::Model/update> instead.
@@ -3094,7 +3107,7 @@ Use L<HTML::FormFu::Model/update> instead.
 
 =head1 DEPRECATION POLICY
 
-We try our best to not make incompatable changes, but if they're required
+We try our best to not make incompatible changes, but if they're required
 we'll make every effort possible to provide backwards compatibility for
 several release-cycles, issuing a warnings about the changes, before removing
 the legacy features.
@@ -3156,7 +3169,7 @@ IRC:
 
 C<irc.perl.org>, channel C<#formfu>
 
-The L<HTML::Widget archives|http://lists.scsys.co.uk/pipermail/html-widget/>
+The HTML::Widget archives L<http://lists.scsys.co.uk/pipermail/html-widget/>
 between January and May 2007 also contain discussion regarding HTML::FormFu.
 
 =head1 BUGS
@@ -3229,3 +3242,5 @@ C<sri@oook.de>.
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
