@@ -4,7 +4,7 @@ use strict;
 use base 'HTML::FormFu::Element::Block';
 
 use HTML::FormFu::Util qw( DEBUG_PROCESS debug );
-use Class::C3;
+use mro 'c3';
 use List::Util qw( first );
 use Carp qw( croak );
 
@@ -116,7 +116,7 @@ sub _repeat_containing_block {
                     $field->original_name($name)
                         if !defined $field->original_name;
 
-                    # store original nested name for later usage when 
+                    # store original nested name for later usage when
                     # replacing the field names in constraints
                     $field->original_nested_name( $field->build_original_nested_name )
                         if !defined $field->original_nested_name;
@@ -310,11 +310,24 @@ sub _reparent_children {
 sub process {
     my $self = shift;
 
-    my $form  = $self->form;
-    my $count = 1;
+    my $counter_name = $self->counter_name;
+    my $form         = $self->form;
+    my $count        = 1;
 
-    if ( defined $self->counter_name && defined $form->query ) {
-        my $input = $form->query->param( $self->counter_name );
+    if ( defined $counter_name && defined $form->query ) {
+        # are we in a nested-repeatable?
+        my $parent = $self;
+
+        while ( defined( $parent = $parent->parent ) ) {
+            my $field = $parent->get_field({ original_name => $counter_name });
+
+            if ( defined $field ) {
+                $counter_name = $field->nested_name;
+                last;
+            }
+        }
+
+        my $input = $form->query->param( $counter_name );
 
         if ( defined $input && $input =~ /^[1-9][0-9]*\z/ ) {
             $count = $input;
@@ -383,8 +396,8 @@ Calling C<< $element->repeat(2) >> would result in the following markup:
         <input name="my_rep.bar_1" type="text" />
     </div>
     <div>
-        <input name="myrep.foo_2" type="text" />
-        <input name="myrep.bar_2" type="text" />
+        <input name="my_rep.foo_2" type="text" />
+        <input name="my_rep.bar_2" type="text" />
     </div>
 
 Example of constraints:
@@ -395,13 +408,13 @@ Example of constraints:
         name: my_rep
         elements:
           - name: id
-          
+
           - name: foo
             constraints:
               - type: Required
                 when:
                   field: 'my_rep.id' # use full nested-name
-          
+
           - name: bar
             constraints:
               - type: Equal
@@ -409,16 +422,16 @@ Example of constraints:
 
 =head1 DESCRIPTION
 
-Provides a way to extend a form at run-time, by copying and repeating its 
+Provides a way to extend a form at run-time, by copying and repeating its
 child elements.
 
 The elements intended for copying must be added before L</repeat> is called.
 
-Although the Repeatable element inherits from 
-L<Block|HTML::FormFu::Element::Block>, it doesn't generate a block tag 
-around all the repeated elements - instead it places each repeat of the 
-elements in a new L<Block|HTML::FormFu::Element::Block> element, which 
-inherits the Repeatable's display settings, such as L</attributes> and 
+Although the Repeatable element inherits from
+L<Block|HTML::FormFu::Element::Block>, it doesn't generate a block tag
+around all the repeated elements - instead it places each repeat of the
+elements in a new L<Block|HTML::FormFu::Element::Block> element, which
+inherits the Repeatable's display settings, such as L</attributes> and
 L</tag>.
 
 For all constraints attached to fields within a Repeatable block which use
@@ -442,31 +455,32 @@ If no argument C<$count> is provided, it defaults to C<1>.
 Note that C<< $form->process >> will call L</repeat> automatically to ensure the
 initial child elements are correctly set up - unless you call L</repeat>
 manually first, in which case the child elements you created will be left
-untouched (otherwise L</process> would overwrite your changes).
+untouched (otherwise L<process|HTML::FormFu/process> would overwrite your
+changes).
 
-Any subsequent call to L</repeat> will delete the previously copied elements 
-before creating new copies - this means you cannot make repeated calls to 
+Any subsequent call to L</repeat> will delete the previously copied elements
+before creating new copies - this means you cannot make repeated calls to
 L</repeat> within a loop to create more copies.
 
-Each copy of the elements returned are contained in a new 
-L<Block|HTML::FormFu::Element::Block> element. For example, calling 
-C<< $element->repeat(2) >> on a Repeatable element containing 2 Text fields 
-would return 2 L<Block|HTML::FormFu::Element::Block> elements, each 
+Each copy of the elements returned are contained in a new
+L<Block|HTML::FormFu::Element::Block> element. For example, calling
+C<< $element->repeat(2) >> on a Repeatable element containing 2 Text fields
+would return 2 L<Block|HTML::FormFu::Element::Block> elements, each
 containing a copy of the 2 Text fields.
 
 =head2 counter_name
 
 Arguments: $name
 
-If true, the L<HTML::FormFu/query> will be searched during 
-L<HTML::FormFu/process> for a parameter with the given name. The value for 
-that parameter will be passed to L</repeat>, to automatically create the 
+If true, the L<HTML::FormFu/query> will be searched during
+L<HTML::FormFu/process> for a parameter with the given name. The value for
+that parameter will be passed to L</repeat>, to automatically create the
 new copies.
 
 If L</increment_field_names> is true (the default), this is essential: if the
-elements corresponding to the new fieldnames (foo_1, bar_2, etc.) are not 
-present on the form during L<HTML::FormFu/process>, no Processors 
-(Constraints, etc.) will be run on the fields, and their values will not 
+elements corresponding to the new fieldnames (foo_1, bar_2, etc.) are not
+present on the form during L<HTML::FormFu/process>, no Processors
+(Constraints, etc.) will be run on the fields, and their values will not
 be returned by L<HTML::FormFu/params> or L<HTML::FormFu/param>.
 
 =head2 increment_field_names
@@ -480,17 +494,19 @@ C<n> is the L</repeatable_count> value.
 
 =head2 repeatable_count
 
-This is set on each new L<Block|HTML::FormFu::Element::Block> element 
+This is set on each new L<Block|HTML::FormFu::Element::Block> element
 returned by L</repeat>, starting at number C<1>.
 
 Because this is an 'inherited accessor' available on all elements, it can be
 used to determine whether any element is a child of a Repeatable element.
 
+Only available after L<repeat> has been called.
+
 =head2 nested_name
 
-If the L</nested_name> attribute is set the naming scheme of the Repeatable
-elements children is switched to add the counter to the repeatable blocks
-themself.
+If the L</nested_name> attribute is set, the naming scheme of the Repeatable
+element's children is switched to add the counter to the repeatable blocks
+themselves.
 
     ---
     elements:
@@ -507,8 +523,8 @@ Calling C<< $element->repeat(2) >> would result in the following markup:
         <input name="my_rep_1.bar" type="text" />
     </div>
     <div>
-        <input name="myrep_2.foo" type="text" />
-        <input name="myrep_2.bar" type="text" />
+        <input name="my_rep_2.foo" type="text" />
+        <input name="my_rep_2.bar" type="text" />
     </div>
 
 
@@ -525,7 +541,7 @@ Any attributes set will be passed to every repeated Block of elements.
     elements:
       - type: Repeatable
         name: my_rep
-        attributes: 
+        attributes:
           class: rep
         elements:
           - name: foo
@@ -562,14 +578,14 @@ Calling C<< $element->repeat(2) >> would result in the following markup:
         <input name="my_rep.foo_2" type="text" />
     </span>
 
-See L<HTML::FormFu::Element::block/tag> for details.
+See L<HTML::FormFu::Element::Block/tag> for details.
 
 =head2 auto_id
 
-As well as the usual subtitutions, any instances of C<%r> will be 
+As well as the usual subtitutions, any instances of C<%r> will be
 replaced with the value of L</repeatable_count>.
 
-See L<HTML::FormFu::Element::block/auto_id> for further details.
+See L<HTML::FormFu::Element::Block/auto_id> for further details.
 
     ---
     elements:
@@ -593,10 +609,24 @@ Calling C<< $element->repeat(2) >> would result in the following markup:
 Not supported for Repeatable elements - will throw a fatal error if called as
 a setter.
 
+=head1 CAVEATS
+
+=head2 Unsupported Constraints
+
+Note that constraints with an L<others|HTML::FormFu::Constraint::_others> 
+method do not work correctly within a Repeatable block. Currently, these are:
+L<AllOrNone|HTML::FormFu::Constraint::AllOrNone>, 
+L<DependOn|HTML::FormFu::Constraint::DependOn>, 
+L<Equal|HTML::FormFu::Constraint::Equal>, 
+L<MinMaxFields|HTML::FormFu::Constraint::MinMaxFields>, 
+L<reCAPTCHA|HTML::FormFu::Constraint::reCAPTCHA>.
+Also, the L<CallbackOnce|HTML::FormFu::Constraint::CallbackOnce> constraint
+won't work within a Repeatable block, as it wouldn't make much sense.
+
 =head1 SEE ALSO
 
-Is a sub-class of, and inherits methods from 
-L<HTML::FormFu::Element::Block>, 
+Is a sub-class of, and inherits methods from
+L<HTML::FormFu::Element::Block>,
 L<HTML::FormFu::Element>
 
 L<HTML::FormFu>
@@ -609,3 +639,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
